pub struct EncryptionKey {
pub n: BigInt,
pub nn: BigInt,
}Expand description
Public encryption key.
Fields
n: BigIntnn: BigIntTrait Implementations
Sourceimpl<'c, 'm, 'd> Add<EncryptionKey, RawCiphertext<'c>, RawPlaintext<'m>, RawCiphertext<'d>> for Paillier
impl<'c, 'm, 'd> Add<EncryptionKey, RawCiphertext<'c>, RawPlaintext<'m>, RawCiphertext<'d>> for Paillier
Sourcefn add(
ek: &EncryptionKey,
c: RawCiphertext<'c>,
m: RawPlaintext<'m>,
) -> RawCiphertext<'d>
fn add( ek: &EncryptionKey, c: RawCiphertext<'c>, m: RawPlaintext<'m>, ) -> RawCiphertext<'d>
Homomorphically combine ciphertexts
c1 and c2 to obtain a ciphertext containing
the sum of the two underlying plaintexts, reduced modulus n from ek.Sourceimpl<'c1, 'c2, 'd> Add<EncryptionKey, RawCiphertext<'c1>, RawCiphertext<'c2>, RawCiphertext<'d>> for Paillier
impl<'c1, 'c2, 'd> Add<EncryptionKey, RawCiphertext<'c1>, RawCiphertext<'c2>, RawCiphertext<'d>> for Paillier
Sourcefn add(
ek: &EncryptionKey,
c1: RawCiphertext<'c1>,
c2: RawCiphertext<'c2>,
) -> RawCiphertext<'d>
fn add( ek: &EncryptionKey, c1: RawCiphertext<'c1>, c2: RawCiphertext<'c2>, ) -> RawCiphertext<'d>
Homomorphically combine ciphertexts
c1 and c2 to obtain a ciphertext containing
the sum of the two underlying plaintexts, reduced modulus n from ek.Sourceimpl<'c, 'm, 'd> Add<EncryptionKey, RawPlaintext<'m>, RawCiphertext<'c>, RawCiphertext<'d>> for Paillier
impl<'c, 'm, 'd> Add<EncryptionKey, RawPlaintext<'m>, RawCiphertext<'c>, RawCiphertext<'d>> for Paillier
Sourcefn add(
ek: &EncryptionKey,
m: RawPlaintext<'m>,
c: RawCiphertext<'c>,
) -> RawCiphertext<'d>
fn add( ek: &EncryptionKey, m: RawPlaintext<'m>, c: RawCiphertext<'c>, ) -> RawCiphertext<'d>
Homomorphically combine ciphertexts
c1 and c2 to obtain a ciphertext containing
the sum of the two underlying plaintexts, reduced modulus n from ek.Sourceimpl Clone for EncryptionKey
impl Clone for EncryptionKey
Sourcefn clone(&self) -> EncryptionKey
fn clone(&self) -> EncryptionKey
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EncryptionKey
impl Debug for EncryptionKey
Sourceimpl<'de> Deserialize<'de> for EncryptionKey
impl<'de> Deserialize<'de> for EncryptionKey
Sourcefn deserialize<D: Deserializer<'de>>(deserializer: D) -> Result<Self, D::Error>
fn deserialize<D: Deserializer<'de>>(deserializer: D) -> Result<Self, D::Error>
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<'m, 'd> Encrypt<EncryptionKey, RawPlaintext<'m>, RawCiphertext<'d>> for Paillier
impl<'m, 'd> Encrypt<EncryptionKey, RawPlaintext<'m>, RawCiphertext<'d>> for Paillier
Sourcefn encrypt(ek: &EncryptionKey, m: RawPlaintext<'m>) -> RawCiphertext<'d>
fn encrypt(ek: &EncryptionKey, m: RawPlaintext<'m>) -> RawCiphertext<'d>
Encrypt plaintext
m under key ek into a ciphertext.Sourceimpl<'m, 'r, 'd> EncryptWithChosenRandomness<EncryptionKey, RawPlaintext<'m>, &'r PrecomputedRandomness, RawCiphertext<'d>> for Paillier
impl<'m, 'r, 'd> EncryptWithChosenRandomness<EncryptionKey, RawPlaintext<'m>, &'r PrecomputedRandomness, RawCiphertext<'d>> for Paillier
fn encrypt_with_chosen_randomness( ek: &EncryptionKey, m: RawPlaintext<'m>, rn: &'r PrecomputedRandomness, ) -> RawCiphertext<'d>
Sourceimpl<'m, 'r, 'd> EncryptWithChosenRandomness<EncryptionKey, RawPlaintext<'m>, &'r Randomness, RawCiphertext<'d>> for Paillier
impl<'m, 'r, 'd> EncryptWithChosenRandomness<EncryptionKey, RawPlaintext<'m>, &'r Randomness, RawCiphertext<'d>> for Paillier
fn encrypt_with_chosen_randomness( ek: &EncryptionKey, m: RawPlaintext<'m>, r: &'r Randomness, ) -> RawCiphertext<'d>
Sourceimpl<'e> From<&'e EncryptionKey> for MinimalEncryptionKey
impl<'e> From<&'e EncryptionKey> for MinimalEncryptionKey
Sourcefn from(ek: &'e EncryptionKey) -> Self
fn from(ek: &'e EncryptionKey) -> Self
Converts to this type from the input type.
Sourceimpl<'kp> From<&'kp Keypair> for EncryptionKey
impl<'kp> From<&'kp Keypair> for EncryptionKey
Sourceimpl<'n> From<&'n Mpz> for EncryptionKey
impl<'n> From<&'n Mpz> for EncryptionKey
Sourceimpl<'e> From<MinimalEncryptionKey> for EncryptionKey
impl<'e> From<MinimalEncryptionKey> for EncryptionKey
Sourcefn from(ek: MinimalEncryptionKey) -> Self
fn from(ek: MinimalEncryptionKey) -> Self
Converts to this type from the input type.
Sourceimpl<'c, 'm, 'd> Mul<EncryptionKey, RawCiphertext<'c>, RawPlaintext<'m>, RawCiphertext<'d>> for Paillier
impl<'c, 'm, 'd> Mul<EncryptionKey, RawCiphertext<'c>, RawPlaintext<'m>, RawCiphertext<'d>> for Paillier
Sourcefn mul(
ek: &EncryptionKey,
c: RawCiphertext<'c>,
m: RawPlaintext<'m>,
) -> RawCiphertext<'d>
fn mul( ek: &EncryptionKey, c: RawCiphertext<'c>, m: RawPlaintext<'m>, ) -> RawCiphertext<'d>
Homomorphically combine ciphertext
c1 and plaintext m2 to obtain a ciphertext
containing the multiplication of the (underlying) plaintexts, reduced modulus n from ek.Sourceimpl<'c, 'm, 'd> Mul<EncryptionKey, RawPlaintext<'m>, RawCiphertext<'c>, RawCiphertext<'d>> for Paillier
impl<'c, 'm, 'd> Mul<EncryptionKey, RawPlaintext<'m>, RawCiphertext<'c>, RawCiphertext<'d>> for Paillier
Sourcefn mul(
ek: &EncryptionKey,
m: RawPlaintext<'m>,
c: RawCiphertext<'c>,
) -> RawCiphertext<'d>
fn mul( ek: &EncryptionKey, m: RawPlaintext<'m>, c: RawCiphertext<'c>, ) -> RawCiphertext<'d>
Homomorphically combine ciphertext
c1 and plaintext m2 to obtain a ciphertext
containing the multiplication of the (underlying) plaintexts, reduced modulus n from ek.Sourceimpl PartialEq for EncryptionKey
impl PartialEq for EncryptionKey
Sourceimpl<'ek, 'r> PrecomputeRandomness<&'ek EncryptionKey, &'r Mpz, PrecomputedRandomness> for Paillier
impl<'ek, 'r> PrecomputeRandomness<&'ek EncryptionKey, &'r Mpz, PrecomputedRandomness> for Paillier
fn precompute(ek: &'ek EncryptionKey, r: &'r BigInt) -> PrecomputedRandomness
Sourceimpl<'c, 'd> Rerandomize<EncryptionKey, RawCiphertext<'c>, RawCiphertext<'d>> for Paillier
impl<'c, 'd> Rerandomize<EncryptionKey, RawCiphertext<'c>, RawCiphertext<'d>> for Paillier
Sourcefn rerandomize(ek: &EncryptionKey, c: RawCiphertext<'c>) -> RawCiphertext<'d>
fn rerandomize(ek: &EncryptionKey, c: RawCiphertext<'c>) -> RawCiphertext<'d>
Rerandomise ciphertext
c to hide any history of which homomorphic operations were
used to compute it, making it look exactly like a fresh encryption of the same plaintext.Sourceimpl Serialize for EncryptionKey
impl Serialize for EncryptionKey
impl StructuralPartialEq for EncryptionKey